#

###

###

    	genome tags

    		# strand
    			# sequence

    		# chromosome

    		# gene expression regulators
    			# promotoers
    			# enhancers
    			# silencers
    			# insulators

    		# integenic regions

    		# rope
    		# ladder
    			# triple helix

    		{
    			journal,

    			chronical,

    			evolution,
    			progress,
    			progression,

    			development,

    			continuum,

    			series,
    			history,
    			schedule,

    			line,

    			ancestry,
    			geneology,
    			timeline,
    			posterity,

    			chain,
    			sequence,
    			structures,
    			tables,
    			sequences,
    			blockchains,
    			ledgers
    		}

    	demux

    		blockchain:genome
    			# genome

    		squeeze:

    		block:gene

    		tx:sequence
    			# strand

    	thoughts

    		genetics
    		genome (aggregate)
    		gene
    		sequence